@@ -105,7 +105,7 @@ export const SidebarList = styled.div`
     display: flex;
     flex-direction: column;
     align-items: center;
-    height: 181px;
+    // height: 181px;
     width: 47px;
 `;
 export const SidebarListItem = styled.div`
@@ -116,7 +116,7 @@ export const SidebarListItem = styled.div`
     height: 45px;
     width: 100%;
     &:not(:last-of-type) {
-        margin-bottom: 10px;
+        margin-bottom: 0px;
     }
     border-left: 4px solid
         ${(props) =>
@@ -137,6 +137,20 @@ export const SidebarListItem = styled.div`
             ${(props) => (props.selected ? "rgba(25, 118, 210, 1)" : "black")};
     }
 `;
+
+export const MainContainerDivider = styled(Divider)`
+    display: flex;
+    align-items: center;
+`;
+
+export const SideBarDividerContainer = styled.div`
+    padding: 0px 0px;
+    display: flex;
+    align-items: center;
+    justify-content: center;
+    width: 100%;
+`;
+
 export const SidebarButton = styled.div`
     display: flex;
     flex-direction: column;
@@ -151,10 +165,10 @@ export const SidebarIcon = styled.div`
     height: 75%;
 `;
 
-export const SideBarDivider = styled(Divider)`
-    display: flex;
-    align-items: center;
-`;
+// export const SideBarDividerContainer = styled(Divider)`
+//     display: flex;
+//     align-items: center;
+// `;
 
 // export const StyledDividerVertical = styled(
 //   DividerVertical
@@ -424,7 +438,7 @@ export const CodeOutputHeader = styled(Typography)`
 // need this compoent to make the text output respect tab character
 export const CodeOutputContent = styled.div`
     overflow: auto;
-    max-height: 100%;
+    max-height: 90%;
 `;
 // export const IndividualCodeOutputContent = styled.pre`
 //     margin: 0px;
