@@ -1,11 +1,3 @@
-// import '../node_modules/react-grid-layout/css/styles.css';
-// import '../node_modules/react-resizable/css/styles.css';
-// import "font-awesome/css/font-awesome.css";
-// import "@lumino/widgets/style/index.css";
-// import "../lib/@jupyter-widgets/controls/css/widgets-base.css";
-// import "@jupyter-widgets/controls/css/labvariables.css";
-// import "@jupyter-widgets/html-manager/css/output.css";
-
 import { createTheme, StyledEngineProvider, ThemeProvider as MuiThemeProvider } from '@mui/material/styles';
 import type { NextPage } from 'next';
 import React from "react";
@@ -14,8 +6,6 @@ import { Provider } from 'react-redux';
 import store from '../redux/store/index';
 import Main from '../lib/components/Main';
 import ErrorBoundary from "../lib/components/error-boundary/ErrorBoundary";
-// import themes from '../theme';
-// global style
 import { createGlobalStyle, ThemeProvider as StyledThemeProvider } from "styled-components";
 const GlobalStyle = createGlobalStyle`
   body {
@@ -26,21 +16,13 @@ const GlobalStyle = createGlobalStyle`
 const theme = createTheme({});
 
 const Home: NextPage = () => {
-    // useEffect(() => {
-    //     // Remove the server-side injected CSS.
-    //     const jssStyles = document.querySelector('#jss-server-side');
-    //     if (jssStyles)
-    //       if(jssStyles.parentElement)
-    //         jssStyles.parentElement.removeChild(jssStyles);
-    // }, []);
-
     return (
         <Provider store={store}>
             <React.Fragment>
                 <GlobalStyle />
                 <Helmet
-                    titleTemplate='%s | CycAI'
-                    defaultTitle='CycAI - Inteligent Platform for Data Scientists'
+                    titleTemplate='%s | CNext'
+                    defaultTitle='CNext - A Data-Centric Platform for DS and AI Workflows'
                 />
                 <StyledEngineProvider injectFirst>
                     <StyledThemeProvider theme={theme}>
