@@ -4,6 +4,7 @@ import traceback
 import simplejson as json
 import cnextlib.user_space as _cus
 import cnextlib.dataframe as _cd
+from libs.constants import TrackingModelType
 from user_space.ipython.kernel import IPythonKernel
 from user_space.ipython.constants import IPythonInteral, IPythonConstants
 
@@ -49,6 +50,12 @@ class IPythonUserSpace(_cus.UserSpace):
 
     def __init__(self, tracking_df_types: tuple = (), tracking_model_types: tuple = ()):
         self.executor: IPythonKernel = IPythonKernel()
+        self.init_executor()
+        self.execution_lock = threading.Lock()
+        self.result = None
+        super().__init__(tracking_df_types, tracking_model_types)
+
+    def init_executor(self):
         code = """
 import cnextlib.dataframe as _cd
 import pandas as _pd
@@ -60,17 +67,14 @@ class _UserSpace(BaseKernelUserSpace):
     def globals(self):
         return globals()
     
-{_user_space} = _UserSpace((_cd.DataFrame, _pd.DataFrame), ("torch.nn.Module", "tensorflow.keras.Model"))  
+{_user_space} = _UserSpace((_cd.DataFrame, _pd.DataFrame), {tracking_models})  
 {_df_manager} = _dm.MessageHandler(None, {_user_space})
 {_cassist} = _ca.MessageHandler(None, {_user_space})
 """.format(_user_space=IPythonInteral.USER_SPACE.value,
-                _df_manager=IPythonInteral.DF_MANAGER.value,
-                _cassist=IPythonInteral.CASSIST.value)
-            # log.info(code)
+           _df_manager=IPythonInteral.DF_MANAGER.value,
+           _cassist=IPythonInteral.CASSIST.value,
+           tracking_models=(TrackingModelType.PYTORCH_NN,TrackingModelType.TENSORFLOW_KERAS))
         self.executor.execute(code)
-        self.execution_lock = threading.Lock()
-        self.result = None
-        super().__init__(tracking_df_types, tracking_model_types)
 
     def globals(self):
         return globals()
@@ -86,7 +90,7 @@ class _UserSpace(BaseKernelUserSpace):
             #     stream_type, ipython_message['header']['msg_type']))
             if ipython_message['header']['msg_type'] == IPythonConstants.MessageType.EXECUTE_RESULT:
                 self.result = json.loads(
-                    ipython_message['content']['data']['text/plain'])                
+                    ipython_message['content']['data']['text/plain'])
             elif self._complete_execution_message(ipython_message) and self.execution_lock.locked():
                 self.execution_lock.release()
                 log.info('Execution unlocked')
@@ -104,10 +108,11 @@ class _UserSpace(BaseKernelUserSpace):
         '''
         def _result_waiting_execution_wrapper(*args, **kwargs):
             args[0].execution_lock.acquire()
-            log.info('Execution locked')
+            log.info('User_space execution lock acquired')
             func(*args, **kwargs)
             args[0].execution_lock.acquire()
             args[0].execution_lock.release()
+            log.info('User_space execution lock released')
             log.info("Results: %s" % args[0].result)
             return args[0].result
         return _result_waiting_execution_wrapper
@@ -121,7 +126,7 @@ class _UserSpace(BaseKernelUserSpace):
 
         Returns:
             _type_: _description_
-        """        
+        """
         code = "{_user_space}.get_active_dfs_status()".format(
             _user_space=IPythonInteral.USER_SPACE.value)
         log.info('Code to execute %s' % code)
@@ -144,18 +149,36 @@ class _UserSpace(BaseKernelUserSpace):
         self.reset_active_dfs_status()
         return self.executor.execute(code, exec_mode, message_handler_callback, client_message)
 
-    def shutdown(self):        
+    def shutdown_executor(self):
         self.executor.shutdown_kernel()
-        ## not sure if this is needed
         if self.execution_lock.locked():
             self.execution_lock.release()
 
+    def restart_executor(self):
+        result = self.executor.restart_kernel()
+        self.init_executor()
+        if self.execution_lock.locked():
+            self.execution_lock.release()
+        return result
+
+    def interrupt_executor(self):
+        result = self.executor.interrupt_kernel()
+        if self.execution_lock.locked():
+            self.execution_lock.release()
+        return result
+    
+    def set_executor_working_dir(self, path):
+        code = "import os; os.chdir('{}')".format(path)
+        return self.executor.execute(code)
+
+
 class BaseKernelUserSpace(_cus.UserSpace):
     ''' 
         Define the space where user code will be executed. 
         This is encapsulated in a python module so all the imports and variables are separated out from the rest.
         The code is executed on a kernel such as BaseKernel or IPythonKernel
     '''
+
     def __init__(self, tracking_df_types: tuple = (), tracking_model_types: tuple = ()):
         self.executor = BaseKernel()
         _cd.DataFrame.set_user_space(self)
@@ -167,6 +190,6 @@ class BaseKernelUserSpace(_cus.UserSpace):
     def execute(self, code, exec_mode: ExecutionMode = None):
         self.reset_active_dfs_status()
         return self.executor.execute(code, exec_mode, self.globals())
-    
-    def shutdown():
+
+    def shutdown_executor(self):
         pass
